@@ -1,6 +1,6 @@
 /*
  * common.h -- Common definitions for X and Windows NT versions of XBoard
- * $Id: common.h,v 1.69 2001/02/04 04:42:43 mann Exp $
+ * $Id: common.h,v 1.70 2001/12/09 23:02:59 mann Exp $
  *
  * Copyright 1991 by Digital Equipment Corporation, Maynard, Massachusetts.
  * Enhancements Copyright 1992-95 Free Software Foundation, Inc.
@@ -133,6 +133,7 @@ int pclose(FILE *);
 #define PREMOVE_HIGHLIGHT_COLOR	"#FF0000"
 #define BELLCHAR                '\007'
 #define NULLCHAR                '\000'
+#define FEATURE_TIMEOUT         10000 /*ms*/
 
 /* Zippy defaults */
 #define ZIPPY_TALK FALSE
@@ -217,7 +218,7 @@ typedef enum {
     VariantKriegspiel,   /* Kriegspiel; pawns can capture invisible pieces */
     VariantAtomic,       /* Capturing piece explodes (ICC wild 27) */
     Variant3Check,       /* Win by giving check 3 times (ICC wild 25) */
-    Variant28,           /* Temporary name for possible future ICC wild 28 */
+    VariantShatranj,     /* Unsupported (ICC wild 28) */
     Variant29,           /* Temporary name for possible future ICC wild 29 */
     Variant30,           /* Temporary name for possible future ICC wild 30 */
     Variant31,           /* Temporary name for possible future ICC wild 31 */
@@ -244,7 +245,7 @@ typedef enum {
   "kriegspiel", \
   "atomic", \
   "3check", \
-  "wild28", \
+  "shatranj", \
   "wild29", \
   "wild30", \
   "wild31", \
@@ -405,6 +406,7 @@ typedef struct {
     char *variant;
     int firstProtocolVersion;
     int secondProtocolVersion;
+    Boolean showButtonBar;
 #if ZIPPY
     char *zippyLines;
     char *zippyPinhead;
