@@ -1,6 +1,6 @@
 /*
  * zippy.c -- Implements Zippy the Pinhead chess player on ICS in XBoard
- * $Id: zippy.c,v 1.62 2001/12/09 23:02:59 mann Exp $
+ * $Id: zippy.c,v 1.63 2001/12/15 22:50:49 mann Exp $
  *
  * Copyright 1991 by Digital Equipment Corporation, Maynard, Massachusetts.
  * Enhancements Copyright 1992-2001 Free Software Foundation, Inc.
@@ -421,11 +421,11 @@ int ZippyControl(buf, i)
     }
 
     /* Tells and says */
-    if (appData.zippyPlay &&
+    if (appData.zippyPlay && 
 	(looking_at(buf, i, "* offers to be your bughouse partner") ||
 	 looking_at(buf, i, "* tells you: [automatic message] I chose you"))) {
 	player = StripHighlightAndTitle(star_match[0]);
-	if (appData.zippyBughouse > 1) {
+	if (appData.zippyBughouse > 1 && first.initDone) {
 	    sprintf(reply, "%spartner %s\n", ics_prefix, player);
 	    SendToICS(reply);
 	    if (strcmp(zippyPartner, player) != 0) {
@@ -443,7 +443,7 @@ int ZippyControl(buf, i)
 	return TRUE;
     }
 
-    if (appData.zippyPlay && appData.zippyBughouse &&
+    if (appData.zippyPlay && appData.zippyBughouse && first.initDone &&
 	looking_at(buf, i, "* agrees to be your partner")) {
 	player = StripHighlightAndTitle(star_match[0]);
 	sprintf(reply, "partner %s\n", player);
@@ -454,7 +454,7 @@ int ZippyControl(buf, i)
 	return TRUE;
     }
 
-    if (appData.zippyPlay && appData.zippyBughouse &&
+    if (appData.zippyPlay && appData.zippyBughouse && first.initDone &&
 	(looking_at(buf, i, "are no longer *'s partner") ||
 	 looking_at(buf, i,
 		    "* tells you: [automatic message] I'm no longer your"))) {
@@ -466,7 +466,7 @@ int ZippyControl(buf, i)
 	return TRUE;
     }
 
-    if (appData.zippyPlay && appData.zippyBughouse &&
+    if (appData.zippyPlay && appData.zippyBughouse && first.initDone &&
 	(looking_at(buf, i, "no longer have a bughouse partner") ||
 	 looking_at(buf, i, "partner has disconnected") ||
 	 looking_at(buf, i, "partner has just chosen a new partner"))) {
@@ -475,7 +475,7 @@ int ZippyControl(buf, i)
       return TRUE;
     }
 
-    if (appData.zippyPlay && appData.zippyBughouse &&
+    if (appData.zippyPlay && appData.zippyBughouse && first.initDone &&
 	looking_at(buf, i, "* (your partner) tells you: *")) {
 	/* This pattern works on FICS but not ICC */
 	player = StripHighlightAndTitle(star_match[0]);
@@ -499,7 +499,7 @@ int ZippyControl(buf, i)
 	    while (*p == ' ') p++;
 	    SendToICS(p);
 	    SendToICS("\n");
-	} else if (appData.zippyPassword2[0] != NULLCHAR &&
+	} else if (appData.zippyPassword2[0] != NULLCHAR && first.initDone &&
 	    strncmp(star_match[1], appData.zippyPassword2,
 		    strlen(appData.zippyPassword2)) == 0) {
 	    p = star_match[1] + strlen(appData.zippyPassword2);
@@ -513,7 +513,7 @@ int ZippyControl(buf, i)
 	    while (*p == ' ') p++;
 	    sprintf(reply, "wrong %s\n", player);
 	    SendToICS(reply);
-	} else if (appData.zippyBughouse &&
+	} else if (appData.zippyBughouse && first.initDone &&
 		   strcmp(player, zippyPartner) == 0) {
 	    SendToProgram("ptell ", &first);
 	    SendToProgram(star_match[1], &first);
@@ -693,6 +693,15 @@ int ZippyConverse(buf, i)
 void ZippyGameStart(white, black)
      char *white, *black;
 {
+    if (!first.initDone) {
+      /* Game is starting prematurely.  We can't deal with this */
+      SendToICS(ics_prefix);
+      SendToICS("abort\n");
+      SendToICS(ics_prefix);
+      SendToICS("say Sorry, the chess program is not initialized yet.\n");
+      return;
+    }
+
     if (appData.zippyGameStart[0] != NULLCHAR) {
       SendToICS(appData.zippyGameStart);
       SendToICS("\n");
@@ -770,8 +779,8 @@ void ZippyHandleChallenge(srated, swild, sbase, sincrement, opponent)
       return;
     }
 
-    /* Engine still thinking about last game? */
-    if (first.lastPing != first.lastPong) {
+    /* Engine not yet initialized or still thinking about last game? */
+    if (!first.initDone || first.lastPing != first.lastPong) {
       sprintf(buf, "%stell %s I'm not quite ready for a new game yet; try again soon.\n%sdecline %s\n",
 	      ics_prefix, opponent, ics_prefix, opponent);
       SendToICS(buf);
@@ -786,11 +795,11 @@ void ZippyHandleChallenge(srated, swild, sbase, sincrement, opponent)
 }
 
 
+/* Accept matches */
 int ZippyMatch(buf, i)
      char *buf;
      int *i;
 {
-    /* Accept matches */
     if (looking_at(buf, i, "* * match * * requested with * (*)")) {
 
 	ZippyHandleChallenge(star_match[0], star_match[1],
@@ -858,7 +867,7 @@ int ZippyMatch(buf, i)
     }
 
     if (looking_at(buf, i, "offers you a draw")) {
-        if (first.sendDrawOffers) {
+        if (first.sendDrawOffers && first.initDone) {
 	    SendToProgram("draw\n", &first);
 	}
 	return TRUE;
@@ -899,6 +908,9 @@ int ZippyMatch(buf, i)
     return FALSE;
 }
 
+/* Initialize chess program with data from the first board 
+ * of a new or resumed game.
+ */
 void ZippyFirstBoard(moveNum, basetime, increment)
      int moveNum, basetime, increment;
 {
@@ -907,8 +919,14 @@ void ZippyFirstBoard(moveNum, basetime, increment)
     char *opp = (gameMode==IcsPlayingWhite ? gameInfo.black : gameInfo.white);
     Boolean sentPos = FALSE;
 
-    /* Initialize chess program with data from the first board 
-       of a new or resumed game */
+    if (!first.initDone) {
+      /* Game is starting prematurely.  We can't deal with this */
+      SendToICS(ics_prefix);
+      SendToICS("abort\n");
+      SendToICS(ics_prefix);
+      SendToICS("say Sorry, the chess program is not initialized yet.\n");
+      return;
+    }
 
     /* Send the variant command if needed */
     if (gameInfo.variant != VariantNormal) {
